# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ledger_info.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ledger_info.proto',
  package='types',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x11ledger_info.proto\x12\x05types\"\xa8\x01\n\nLedgerInfo\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12$\n\x1ctransaction_accumulator_hash\x18\x02 \x01(\x0c\x12\x1b\n\x13\x63onsensus_data_hash\x18\x03 \x01(\x0c\x12\x1a\n\x12\x63onsensus_block_id\x18\x04 \x01(\x0c\x12\x11\n\tepoch_num\x18\x05 \x01(\x04\x12\x17\n\x0ftimestamp_usecs\x18\x06 \x01(\x04\"q\n\x18LedgerInfoWithSignatures\x12-\n\nsignatures\x18\x01 \x03(\x0b\x32\x19.types.ValidatorSignature\x12&\n\x0bledger_info\x18\x02 \x01(\x0b\x32\x11.types.LedgerInfo\"=\n\x12ValidatorSignature\x12\x14\n\x0cvalidator_id\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x62\x06proto3')
)




_LEDGERINFO = _descriptor.Descriptor(
  name='LedgerInfo',
  full_name='types.LedgerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='types.LedgerInfo.version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_accumulator_hash', full_name='types.LedgerInfo.transaction_accumulator_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consensus_data_hash', full_name='types.LedgerInfo.consensus_data_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consensus_block_id', full_name='types.LedgerInfo.consensus_block_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epoch_num', full_name='types.LedgerInfo.epoch_num', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp_usecs', full_name='types.LedgerInfo.timestamp_usecs', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=197,
)


_LEDGERINFOWITHSIGNATURES = _descriptor.Descriptor(
  name='LedgerInfoWithSignatures',
  full_name='types.LedgerInfoWithSignatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signatures', full_name='types.LedgerInfoWithSignatures.signatures', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_info', full_name='types.LedgerInfoWithSignatures.ledger_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=199,
  serialized_end=312,
)


_VALIDATORSIGNATURE = _descriptor.Descriptor(
  name='ValidatorSignature',
  full_name='types.ValidatorSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_id', full_name='types.ValidatorSignature.validator_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='types.ValidatorSignature.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=375,
)

_LEDGERINFOWITHSIGNATURES.fields_by_name['signatures'].message_type = _VALIDATORSIGNATURE
_LEDGERINFOWITHSIGNATURES.fields_by_name['ledger_info'].message_type = _LEDGERINFO
DESCRIPTOR.message_types_by_name['LedgerInfo'] = _LEDGERINFO
DESCRIPTOR.message_types_by_name['LedgerInfoWithSignatures'] = _LEDGERINFOWITHSIGNATURES
DESCRIPTOR.message_types_by_name['ValidatorSignature'] = _VALIDATORSIGNATURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LedgerInfo = _reflection.GeneratedProtocolMessageType('LedgerInfo', (_message.Message,), dict(
  DESCRIPTOR = _LEDGERINFO,
  __module__ = 'ledger_info_pb2'
  # @@protoc_insertion_point(class_scope:types.LedgerInfo)
  ))
_sym_db.RegisterMessage(LedgerInfo)

LedgerInfoWithSignatures = _reflection.GeneratedProtocolMessageType('LedgerInfoWithSignatures', (_message.Message,), dict(
  DESCRIPTOR = _LEDGERINFOWITHSIGNATURES,
  __module__ = 'ledger_info_pb2'
  # @@protoc_insertion_point(class_scope:types.LedgerInfoWithSignatures)
  ))
_sym_db.RegisterMessage(LedgerInfoWithSignatures)

ValidatorSignature = _reflection.GeneratedProtocolMessageType('ValidatorSignature', (_message.Message,), dict(
  DESCRIPTOR = _VALIDATORSIGNATURE,
  __module__ = 'ledger_info_pb2'
  # @@protoc_insertion_point(class_scope:types.ValidatorSignature)
  ))
_sym_db.RegisterMessage(ValidatorSignature)


# @@protoc_insertion_point(module_scope)



from io import BytesIO


class AccountState(object):
    def __init__(
        self, authentication_key, balance, received_events_count, sent_events_count, sequence_number
    ):
        self.authentication_key = authentication_key
        self.balance = balance
        self.received_events_count = received_events_count
        self.sent_events_count = sent_events_count
        self.sequence_number = sequence_number

    @staticmethod
    def empty(address):
        return AccountState(address, 0, 0, 0, 0)

    @staticmethod
    def from_bytes(data):
        buffer = BytesIO(data)
        authentication_key_len = int.from_bytes(buffer.read(4), byteorder="little")
        authentication_key = buffer.read(authentication_key_len).hex()
        balance = int.from_bytes(buffer.read(8), byteorder="little")
        received_events_count = int.from_bytes(buffer.read(8), byteorder="little")
        sent_events_count = int.from_bytes(buffer.read(8), byteorder="little")
        sequence_number = int.from_bytes(buffer.read(8), byteorder="little")
        return AccountState(
            authentication_key, balance, received_events_count, sent_events_count, sequence_number
        )

    def __str__(self):
        return "AccountState({}, {}, {}, {}, {})".format(
            self.authentication_key,
            self.balance,
            self.received_events_count,
            self.sent_events_count,
            self.sequence_number,
        )




from pylibra.proto.transaction_pb2 import TransactionArgument
from pylibra.transaction.base import TransactionBase


TRANSFER_OPCODES = bytes.fromhex(
    "4c49425241564d0a010007014a00000004000000034e000000060000000c54000000050000000d5900000004000000055d0000002900000004860000002000000007a60000000d00000000000001000200010300020002040203020402063c53454c463e0c4c696272614163636f756e74046d61696e0f7061795f66726f6d5f73656e64657200000000000000000000000000000000000000000000000000000000000000000001020004000c000c01110102"
)


class TransferTransaction(TransactionBase):
    def __init__(self, receiver, value):
        self.receiver = receiver
        self.value = value

    def fill_program(self, program):
        program.code = TRANSFER_OPCODES
        receiver = program.arguments.add()
        receiver.type = TransactionArgument.ADDRESS
        receiver.data = bytes.fromhex(self.receiver)
        value = program.arguments.add()
        value.type = TransactionArgument.U64
        value.data = self.value.to_bytes(8, "little")



from pylibra.proto.transaction_pb2 import RawTransaction


class TransactionBase(object):
    def as_raw_transaction(
        self, sender, sequence_number, max_gas_amount, gas_unit_price, expiration_time
    ):
        raw_tx = RawTransaction()
        raw_tx.sender_account = bytes.fromhex(sender)
        raw_tx.sequence_number = sequence_number
        raw_tx.max_gas_amount = max_gas_amount
        raw_tx.gas_unit_price = gas_unit_price
        raw_tx.expiration_time = expiration_time
        self.fill_program(raw_tx.program)
        return raw_tx

    def fill_program(self, program):
        raise NotImplementedError()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transaction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import access_path_pb2 as access__path__pb2
from . import events_pb2 as events__pb2
from . import proof_pb2 as proof__pb2
from . import transaction_info_pb2 as transaction__info__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='transaction.proto',
  package='types',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x11transaction.proto\x12\x05types\x1a\x11\x61\x63\x63\x65ss_path.proto\x1a\x0c\x65vents.proto\x1a\x0bproof.proto\x1a\x16transaction_info.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xde\x01\n\x0eRawTransaction\x12\x16\n\x0esender_account\x18\x01 \x01(\x0c\x12\x17\n\x0fsequence_number\x18\x02 \x01(\x04\x12!\n\x07program\x18\x03 \x01(\x0b\x32\x0e.types.ProgramH\x00\x12$\n\twrite_set\x18\x04 \x01(\x0b\x32\x0f.types.WriteSetH\x00\x12\x16\n\x0emax_gas_amount\x18\x05 \x01(\x04\x12\x16\n\x0egas_unit_price\x18\x06 \x01(\x04\x12\x17\n\x0f\x65xpiration_time\x18\x07 \x01(\x04\x42\t\n\x07payload\"W\n\x07Program\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x0c\x12-\n\targuments\x18\x02 \x03(\x0b\x32\x1a.types.TransactionArgument\x12\x0f\n\x07modules\x18\x03 \x03(\x0c\"\x91\x01\n\x13TransactionArgument\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".types.TransactionArgument.ArgType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\":\n\x07\x41rgType\x12\x07\n\x03U64\x10\x00\x12\x0b\n\x07\x41\x44\x44RESS\x10\x01\x12\n\n\x06STRING\x10\x02\x12\r\n\tBYTEARRAY\x10\x03\"_\n\x11SignedTransaction\x12\x15\n\rraw_txn_bytes\x18\x01 \x01(\x0c\x12\x19\n\x11sender_public_key\x18\x02 \x01(\x0c\x12\x18\n\x10sender_signature\x18\x03 \x01(\x0c\"\xb4\x01\n\x1aSignedTransactionWithProof\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\x34\n\x12signed_transaction\x18\x02 \x01(\x0b\x32\x18.types.SignedTransaction\x12,\n\x05proof\x18\x03 \x01(\x0b\x32\x1d.types.SignedTransactionProof\x12!\n\x06\x65vents\x18\x04 \x01(\x0b\x32\x11.types.EventsList\"\x84\x01\n\x17SignedTransactionsBlock\x12.\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x18.types.SignedTransaction\x12\x1c\n\x14validator_public_key\x18\x02 \x01(\x0c\x12\x1b\n\x13validator_signature\x18\x03 \x01(\x0c\"-\n\x08WriteSet\x12!\n\twrite_set\x18\x01 \x03(\x0b\x32\x0e.types.WriteOp\"b\n\x07WriteOp\x12&\n\x0b\x61\x63\x63\x65ss_path\x18\x01 \x01(\x0b\x32\x11.types.AccessPath\x12\r\n\x05value\x18\x02 \x01(\x0c\x12 \n\x04type\x18\x03 \x01(\x0e\x32\x12.types.WriteOpType\"-\n\x0c\x41\x63\x63ountState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0c\n\x04\x62lob\x18\x02 \x01(\x0c\"\xa0\x01\n\x13TransactionToCommit\x12,\n\nsigned_txn\x18\x01 \x01(\x0b\x32\x18.types.SignedTransaction\x12+\n\x0e\x61\x63\x63ount_states\x18\x02 \x03(\x0b\x32\x13.types.AccountState\x12\x1c\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x0c.types.Event\x12\x10\n\x08gas_used\x18\x04 \x01(\x04\"\xe2\x02\n\x18TransactionListWithProof\x12.\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x18.types.SignedTransaction\x12%\n\x05infos\x18\x02 \x03(\x0b\x32\x16.types.TransactionInfo\x12\x35\n\x13\x65vents_for_versions\x18\x03 \x01(\x0b\x32\x18.types.EventsForVersions\x12?\n\x19\x66irst_transaction_version\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12;\n\x1aproof_of_first_transaction\x18\x05 \x01(\x0b\x32\x17.types.AccumulatorProof\x12:\n\x19proof_of_last_transaction\x18\x06 \x01(\x0b\x32\x17.types.AccumulatorProof*$\n\x0bWriteOpType\x12\t\n\x05Write\x10\x00\x12\n\n\x06\x44\x65lete\x10\x01\x62\x06proto3')
  ,
  dependencies=[access__path__pb2.DESCRIPTOR,events__pb2.DESCRIPTOR,proof__pb2.DESCRIPTOR,transaction__info__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_WRITEOPTYPE = _descriptor.EnumDescriptor(
  name='WriteOpType',
  full_name='types.WriteOpType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Write', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Delete', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1721,
  serialized_end=1757,
)
_sym_db.RegisterEnumDescriptor(_WRITEOPTYPE)

WriteOpType = enum_type_wrapper.EnumTypeWrapper(_WRITEOPTYPE)
Write = 0
Delete = 1


_TRANSACTIONARGUMENT_ARGTYPE = _descriptor.EnumDescriptor(
  name='ArgType',
  full_name='types.TransactionArgument.ArgType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='U64', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BYTEARRAY', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=532,
  serialized_end=590,
)
_sym_db.RegisterEnumDescriptor(_TRANSACTIONARGUMENT_ARGTYPE)


_RAWTRANSACTION = _descriptor.Descriptor(
  name='RawTransaction',
  full_name='types.RawTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_account', full_name='types.RawTransaction.sender_account', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='types.RawTransaction.sequence_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='program', full_name='types.RawTransaction.program', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write_set', full_name='types.RawTransaction.write_set', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_gas_amount', full_name='types.RawTransaction.max_gas_amount', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gas_unit_price', full_name='types.RawTransaction.gas_unit_price', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiration_time', full_name='types.RawTransaction.expiration_time', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='types.RawTransaction.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=131,
  serialized_end=353,
)


_PROGRAM = _descriptor.Descriptor(
  name='Program',
  full_name='types.Program',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='types.Program.code', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='types.Program.arguments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modules', full_name='types.Program.modules', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=442,
)


_TRANSACTIONARGUMENT = _descriptor.Descriptor(
  name='TransactionArgument',
  full_name='types.TransactionArgument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='types.TransactionArgument.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='types.TransactionArgument.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRANSACTIONARGUMENT_ARGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=590,
)


_SIGNEDTRANSACTION = _descriptor.Descriptor(
  name='SignedTransaction',
  full_name='types.SignedTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_txn_bytes', full_name='types.SignedTransaction.raw_txn_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_public_key', full_name='types.SignedTransaction.sender_public_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_signature', full_name='types.SignedTransaction.sender_signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=687,
)


_SIGNEDTRANSACTIONWITHPROOF = _descriptor.Descriptor(
  name='SignedTransactionWithProof',
  full_name='types.SignedTransactionWithProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='types.SignedTransactionWithProof.version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signed_transaction', full_name='types.SignedTransactionWithProof.signed_transaction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof', full_name='types.SignedTransactionWithProof.proof', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='types.SignedTransactionWithProof.events', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=690,
  serialized_end=870,
)


_SIGNEDTRANSACTIONSBLOCK = _descriptor.Descriptor(
  name='SignedTransactionsBlock',
  full_name='types.SignedTransactionsBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactions', full_name='types.SignedTransactionsBlock.transactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validator_public_key', full_name='types.SignedTransactionsBlock.validator_public_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validator_signature', full_name='types.SignedTransactionsBlock.validator_signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=1005,
)


_WRITESET = _descriptor.Descriptor(
  name='WriteSet',
  full_name='types.WriteSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='write_set', full_name='types.WriteSet.write_set', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1052,
)


_WRITEOP = _descriptor.Descriptor(
  name='WriteOp',
  full_name='types.WriteOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_path', full_name='types.WriteOp.access_path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='types.WriteOp.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='types.WriteOp.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1152,
)


_ACCOUNTSTATE = _descriptor.Descriptor(
  name='AccountState',
  full_name='types.AccountState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='types.AccountState.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob', full_name='types.AccountState.blob', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1154,
  serialized_end=1199,
)


_TRANSACTIONTOCOMMIT = _descriptor.Descriptor(
  name='TransactionToCommit',
  full_name='types.TransactionToCommit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_txn', full_name='types.TransactionToCommit.signed_txn', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_states', full_name='types.TransactionToCommit.account_states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='types.TransactionToCommit.events', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gas_used', full_name='types.TransactionToCommit.gas_used', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1362,
)


_TRANSACTIONLISTWITHPROOF = _descriptor.Descriptor(
  name='TransactionListWithProof',
  full_name='types.TransactionListWithProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactions', full_name='types.TransactionListWithProof.transactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infos', full_name='types.TransactionListWithProof.infos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events_for_versions', full_name='types.TransactionListWithProof.events_for_versions', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_transaction_version', full_name='types.TransactionListWithProof.first_transaction_version', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_of_first_transaction', full_name='types.TransactionListWithProof.proof_of_first_transaction', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_of_last_transaction', full_name='types.TransactionListWithProof.proof_of_last_transaction', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1365,
  serialized_end=1719,
)

_RAWTRANSACTION.fields_by_name['program'].message_type = _PROGRAM
_RAWTRANSACTION.fields_by_name['write_set'].message_type = _WRITESET
_RAWTRANSACTION.oneofs_by_name['payload'].fields.append(
  _RAWTRANSACTION.fields_by_name['program'])
_RAWTRANSACTION.fields_by_name['program'].containing_oneof = _RAWTRANSACTION.oneofs_by_name['payload']
_RAWTRANSACTION.oneofs_by_name['payload'].fields.append(
  _RAWTRANSACTION.fields_by_name['write_set'])
_RAWTRANSACTION.fields_by_name['write_set'].containing_oneof = _RAWTRANSACTION.oneofs_by_name['payload']
_PROGRAM.fields_by_name['arguments'].message_type = _TRANSACTIONARGUMENT
_TRANSACTIONARGUMENT.fields_by_name['type'].enum_type = _TRANSACTIONARGUMENT_ARGTYPE
_TRANSACTIONARGUMENT_ARGTYPE.containing_type = _TRANSACTIONARGUMENT
_SIGNEDTRANSACTIONWITHPROOF.fields_by_name['signed_transaction'].message_type = _SIGNEDTRANSACTION
_SIGNEDTRANSACTIONWITHPROOF.fields_by_name['proof'].message_type = proof__pb2._SIGNEDTRANSACTIONPROOF
_SIGNEDTRANSACTIONWITHPROOF.fields_by_name['events'].message_type = events__pb2._EVENTSLIST
_SIGNEDTRANSACTIONSBLOCK.fields_by_name['transactions'].message_type = _SIGNEDTRANSACTION
_WRITESET.fields_by_name['write_set'].message_type = _WRITEOP
_WRITEOP.fields_by_name['access_path'].message_type = access__path__pb2._ACCESSPATH
_WRITEOP.fields_by_name['type'].enum_type = _WRITEOPTYPE
_TRANSACTIONTOCOMMIT.fields_by_name['signed_txn'].message_type = _SIGNEDTRANSACTION
_TRANSACTIONTOCOMMIT.fields_by_name['account_states'].message_type = _ACCOUNTSTATE
_TRANSACTIONTOCOMMIT.fields_by_name['events'].message_type = events__pb2._EVENT
_TRANSACTIONLISTWITHPROOF.fields_by_name['transactions'].message_type = _SIGNEDTRANSACTION
_TRANSACTIONLISTWITHPROOF.fields_by_name['infos'].message_type = transaction__info__pb2._TRANSACTIONINFO
_TRANSACTIONLISTWITHPROOF.fields_by_name['events_for_versions'].message_type = events__pb2._EVENTSFORVERSIONS
_TRANSACTIONLISTWITHPROOF.fields_by_name['first_transaction_version'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_TRANSACTIONLISTWITHPROOF.fields_by_name['proof_of_first_transaction'].message_type = proof__pb2._ACCUMULATORPROOF
_TRANSACTIONLISTWITHPROOF.fields_by_name['proof_of_last_transaction'].message_type = proof__pb2._ACCUMULATORPROOF
DESCRIPTOR.message_types_by_name['RawTransaction'] = _RAWTRANSACTION
DESCRIPTOR.message_types_by_name['Program'] = _PROGRAM
DESCRIPTOR.message_types_by_name['TransactionArgument'] = _TRANSACTIONARGUMENT
DESCRIPTOR.message_types_by_name['SignedTransaction'] = _SIGNEDTRANSACTION
DESCRIPTOR.message_types_by_name['SignedTransactionWithProof'] = _SIGNEDTRANSACTIONWITHPROOF
DESCRIPTOR.message_types_by_name['SignedTransactionsBlock'] = _SIGNEDTRANSACTIONSBLOCK
DESCRIPTOR.message_types_by_name['WriteSet'] = _WRITESET
DESCRIPTOR.message_types_by_name['WriteOp'] = _WRITEOP
DESCRIPTOR.message_types_by_name['AccountState'] = _ACCOUNTSTATE
DESCRIPTOR.message_types_by_name['TransactionToCommit'] = _TRANSACTIONTOCOMMIT
DESCRIPTOR.message_types_by_name['TransactionListWithProof'] = _TRANSACTIONLISTWITHPROOF
DESCRIPTOR.enum_types_by_name['WriteOpType'] = _WRITEOPTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RawTransaction = _reflection.GeneratedProtocolMessageType('RawTransaction', (_message.Message,), dict(
  DESCRIPTOR = _RAWTRANSACTION,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.RawTransaction)
  ))
_sym_db.RegisterMessage(RawTransaction)

Program = _reflection.GeneratedProtocolMessageType('Program', (_message.Message,), dict(
  DESCRIPTOR = _PROGRAM,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.Program)
  ))
_sym_db.RegisterMessage(Program)

TransactionArgument = _reflection.GeneratedProtocolMessageType('TransactionArgument', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONARGUMENT,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.TransactionArgument)
  ))
_sym_db.RegisterMessage(TransactionArgument)

SignedTransaction = _reflection.GeneratedProtocolMessageType('SignedTransaction', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDTRANSACTION,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.SignedTransaction)
  ))
_sym_db.RegisterMessage(SignedTransaction)

SignedTransactionWithProof = _reflection.GeneratedProtocolMessageType('SignedTransactionWithProof', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDTRANSACTIONWITHPROOF,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.SignedTransactionWithProof)
  ))
_sym_db.RegisterMessage(SignedTransactionWithProof)

SignedTransactionsBlock = _reflection.GeneratedProtocolMessageType('SignedTransactionsBlock', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDTRANSACTIONSBLOCK,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.SignedTransactionsBlock)
  ))
_sym_db.RegisterMessage(SignedTransactionsBlock)

WriteSet = _reflection.GeneratedProtocolMessageType('WriteSet', (_message.Message,), dict(
  DESCRIPTOR = _WRITESET,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.WriteSet)
  ))
_sym_db.RegisterMessage(WriteSet)

WriteOp = _reflection.GeneratedProtocolMessageType('WriteOp', (_message.Message,), dict(
  DESCRIPTOR = _WRITEOP,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.WriteOp)
  ))
_sym_db.RegisterMessage(WriteOp)

AccountState = _reflection.GeneratedProtocolMessageType('AccountState', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTSTATE,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.AccountState)
  ))
_sym_db.RegisterMessage(AccountState)

TransactionToCommit = _reflection.GeneratedProtocolMessageType('TransactionToCommit', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONTOCOMMIT,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.TransactionToCommit)
  ))
_sym_db.RegisterMessage(TransactionToCommit)

TransactionListWithProof = _reflection.GeneratedProtocolMessageType('TransactionListWithProof', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONLISTWITHPROOF,
  __module__ = 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:types.TransactionListWithProof)
  ))
_sym_db.RegisterMessage(TransactionListWithProof)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_with_proof.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import access_path_pb2 as access__path__pb2
from . import account_state_blob_pb2 as account__state__blob__pb2
from . import events_pb2 as events__pb2
from . import ledger_info_pb2 as ledger__info__pb2
from . import transaction_pb2 as transaction__pb2
from . import validator_change_pb2 as validator__change__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='get_with_proof.proto',
  package='types',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x14get_with_proof.proto\x12\x05types\x1a\x11\x61\x63\x63\x65ss_path.proto\x1a\x18\x61\x63\x63ount_state_blob.proto\x1a\x0c\x65vents.proto\x1a\x11ledger_info.proto\x1a\x11transaction.proto\x1a\x16validator_change.proto\"h\n\x1bUpdateToLatestLedgerRequest\x12\x1c\n\x14\x63lient_known_version\x18\x01 \x01(\x04\x12+\n\x0frequested_items\x18\x02 \x03(\x0b\x32\x12.types.RequestItem\"\xf7\x02\n\x0bRequestItem\x12\x42\n\x19get_account_state_request\x18\x01 \x01(\x0b\x32\x1d.types.GetAccountStateRequestH\x00\x12q\n2get_account_transaction_by_sequence_number_request\x18\x02 \x01(\x0b\x32\x33.types.GetAccountTransactionBySequenceNumberRequestH\x00\x12[\n\'get_events_by_event_access_path_request\x18\x03 \x01(\x0b\x32(.types.GetEventsByEventAccessPathRequestH\x00\x12\x41\n\x18get_transactions_request\x18\x04 \x01(\x0b\x32\x1d.types.GetTransactionsRequestH\x00\x42\x11\n\x0frequested_items\"\xd2\x01\n\x1cUpdateToLatestLedgerResponse\x12+\n\x0eresponse_items\x18\x01 \x03(\x0b\x32\x13.types.ResponseItem\x12>\n\x15ledger_info_with_sigs\x18\x02 \x01(\x0b\x32\x1f.types.LedgerInfoWithSignatures\x12\x45\n\x17validator_change_events\x18\x03 \x03(\x0b\x32$.types.ValidatorChangeEventWithProof\"\xff\x02\n\x0cResponseItem\x12\x44\n\x1aget_account_state_response\x18\x03 \x01(\x0b\x32\x1e.types.GetAccountStateResponseH\x00\x12s\n3get_account_transaction_by_sequence_number_response\x18\x04 \x01(\x0b\x32\x34.types.GetAccountTransactionBySequenceNumberResponseH\x00\x12]\n(get_events_by_event_access_path_response\x18\x05 \x01(\x0b\x32).types.GetEventsByEventAccessPathResponseH\x00\x12\x43\n\x19get_transactions_response\x18\x06 \x01(\x0b\x32\x1e.types.GetTransactionsResponseH\x00\x42\x10\n\x0eresponse_items\")\n\x16GetAccountStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\"Y\n\x17GetAccountStateResponse\x12>\n\x18\x61\x63\x63ount_state_with_proof\x18\x01 \x01(\x0b\x32\x1c.types.AccountStateWithProof\"n\n,GetAccountTransactionBySequenceNumberRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0c\x12\x17\n\x0fsequence_number\x18\x02 \x01(\x04\x12\x14\n\x0c\x66\x65tch_events\x18\x03 \x01(\x08\"\xc1\x01\n-GetAccountTransactionBySequenceNumberResponse\x12H\n\x1dsigned_transaction_with_proof\x18\x02 \x01(\x0b\x32!.types.SignedTransactionWithProof\x12\x46\n proof_of_current_sequence_number\x18\x03 \x01(\x0b\x32\x1c.types.AccountStateWithProof\"\x8a\x01\n!GetEventsByEventAccessPathRequest\x12&\n\x0b\x61\x63\x63\x65ss_path\x18\x01 \x01(\x0b\x32\x11.types.AccessPath\x12\x1b\n\x13start_event_seq_num\x18\x02 \x01(\x04\x12\x11\n\tascending\x18\x03 \x01(\x08\x12\r\n\x05limit\x18\x04 \x01(\x04\"\x93\x01\n\"GetEventsByEventAccessPathResponse\x12\x30\n\x11\x65vents_with_proof\x18\x01 \x03(\x0b\x32\x15.types.EventWithProof\x12;\n\x15proof_of_latest_event\x18\x02 \x01(\x0b\x32\x1c.types.AccountStateWithProof\"T\n\x16GetTransactionsRequest\x12\x15\n\rstart_version\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x14\n\x0c\x66\x65tch_events\x18\x03 \x01(\x08\"W\n\x17GetTransactionsResponse\x12<\n\x13txn_list_with_proof\x18\x01 \x01(\x0b\x32\x1f.types.TransactionListWithProofb\x06proto3')
  ,
  dependencies=[access__path__pb2.DESCRIPTOR,account__state__blob__pb2.DESCRIPTOR,events__pb2.DESCRIPTOR,ledger__info__pb2.DESCRIPTOR,transaction__pb2.DESCRIPTOR,validator__change__pb2.DESCRIPTOR,])




_UPDATETOLATESTLEDGERREQUEST = _descriptor.Descriptor(
  name='UpdateToLatestLedgerRequest',
  full_name='types.UpdateToLatestLedgerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_known_version', full_name='types.UpdateToLatestLedgerRequest.client_known_version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requested_items', full_name='types.UpdateToLatestLedgerRequest.requested_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=256,
)


_REQUESTITEM = _descriptor.Descriptor(
  name='RequestItem',
  full_name='types.RequestItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_account_state_request', full_name='types.RequestItem.get_account_state_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_account_transaction_by_sequence_number_request', full_name='types.RequestItem.get_account_transaction_by_sequence_number_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_events_by_event_access_path_request', full_name='types.RequestItem.get_events_by_event_access_path_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_transactions_request', full_name='types.RequestItem.get_transactions_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='requested_items', full_name='types.RequestItem.requested_items',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=259,
  serialized_end=634,
)


_UPDATETOLATESTLEDGERRESPONSE = _descriptor.Descriptor(
  name='UpdateToLatestLedgerResponse',
  full_name='types.UpdateToLatestLedgerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_items', full_name='types.UpdateToLatestLedgerResponse.response_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_info_with_sigs', full_name='types.UpdateToLatestLedgerResponse.ledger_info_with_sigs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validator_change_events', full_name='types.UpdateToLatestLedgerResponse.validator_change_events', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=847,
)


_RESPONSEITEM = _descriptor.Descriptor(
  name='ResponseItem',
  full_name='types.ResponseItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_account_state_response', full_name='types.ResponseItem.get_account_state_response', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_account_transaction_by_sequence_number_response', full_name='types.ResponseItem.get_account_transaction_by_sequence_number_response', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_events_by_event_access_path_response', full_name='types.ResponseItem.get_events_by_event_access_path_response', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_transactions_response', full_name='types.ResponseItem.get_transactions_response', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response_items', full_name='types.ResponseItem.response_items',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=850,
  serialized_end=1233,
)


_GETACCOUNTSTATEREQUEST = _descriptor.Descriptor(
  name='GetAccountStateRequest',
  full_name='types.GetAccountStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='types.GetAccountStateRequest.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1235,
  serialized_end=1276,
)


_GETACCOUNTSTATERESPONSE = _descriptor.Descriptor(
  name='GetAccountStateResponse',
  full_name='types.GetAccountStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_state_with_proof', full_name='types.GetAccountStateResponse.account_state_with_proof', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1278,
  serialized_end=1367,
)


_GETACCOUNTTRANSACTIONBYSEQUENCENUMBERREQUEST = _descriptor.Descriptor(
  name='GetAccountTransactionBySequenceNumberRequest',
  full_name='types.GetAccountTransactionBySequenceNumberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='types.GetAccountTransactionBySequenceNumberRequest.account', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='types.GetAccountTransactionBySequenceNumberRequest.sequence_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fetch_events', full_name='types.GetAccountTransactionBySequenceNumberRequest.fetch_events', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1369,
  serialized_end=1479,
)


_GETACCOUNTTRANSACTIONBYSEQUENCENUMBERRESPONSE = _descriptor.Descriptor(
  name='GetAccountTransactionBySequenceNumberResponse',
  full_name='types.GetAccountTransactionBySequenceNumberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_transaction_with_proof', full_name='types.GetAccountTransactionBySequenceNumberResponse.signed_transaction_with_proof', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_of_current_sequence_number', full_name='types.GetAccountTransactionBySequenceNumberResponse.proof_of_current_sequence_number', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1482,
  serialized_end=1675,
)


_GETEVENTSBYEVENTACCESSPATHREQUEST = _descriptor.Descriptor(
  name='GetEventsByEventAccessPathRequest',
  full_name='types.GetEventsByEventAccessPathRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_path', full_name='types.GetEventsByEventAccessPathRequest.access_path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_event_seq_num', full_name='types.GetEventsByEventAccessPathRequest.start_event_seq_num', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ascending', full_name='types.GetEventsByEventAccessPathRequest.ascending', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='types.GetEventsByEventAccessPathRequest.limit', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=1816,
)


_GETEVENTSBYEVENTACCESSPATHRESPONSE = _descriptor.Descriptor(
  name='GetEventsByEventAccessPathResponse',
  full_name='types.GetEventsByEventAccessPathResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='events_with_proof', full_name='types.GetEventsByEventAccessPathResponse.events_with_proof', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof_of_latest_event', full_name='types.GetEventsByEventAccessPathResponse.proof_of_latest_event', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1819,
  serialized_end=1966,
)


_GETTRANSACTIONSREQUEST = _descriptor.Descriptor(
  name='GetTransactionsRequest',
  full_name='types.GetTransactionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_version', full_name='types.GetTransactionsRequest.start_version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='types.GetTransactionsRequest.limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fetch_events', full_name='types.GetTransactionsRequest.fetch_events', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1968,
  serialized_end=2052,
)


_GETTRANSACTIONSRESPONSE = _descriptor.Descriptor(
  name='GetTransactionsResponse',
  full_name='types.GetTransactionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_list_with_proof', full_name='types.GetTransactionsResponse.txn_list_with_proof', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2054,
  serialized_end=2141,
)

_UPDATETOLATESTLEDGERREQUEST.fields_by_name['requested_items'].message_type = _REQUESTITEM
_REQUESTITEM.fields_by_name['get_account_state_request'].message_type = _GETACCOUNTSTATEREQUEST
_REQUESTITEM.fields_by_name['get_account_transaction_by_sequence_number_request'].message_type = _GETACCOUNTTRANSACTIONBYSEQUENCENUMBERREQUEST
_REQUESTITEM.fields_by_name['get_events_by_event_access_path_request'].message_type = _GETEVENTSBYEVENTACCESSPATHREQUEST
_REQUESTITEM.fields_by_name['get_transactions_request'].message_type = _GETTRANSACTIONSREQUEST
_REQUESTITEM.oneofs_by_name['requested_items'].fields.append(
  _REQUESTITEM.fields_by_name['get_account_state_request'])
_REQUESTITEM.fields_by_name['get_account_state_request'].containing_oneof = _REQUESTITEM.oneofs_by_name['requested_items']
_REQUESTITEM.oneofs_by_name['requested_items'].fields.append(
  _REQUESTITEM.fields_by_name['get_account_transaction_by_sequence_number_request'])
_REQUESTITEM.fields_by_name['get_account_transaction_by_sequence_number_request'].containing_oneof = _REQUESTITEM.oneofs_by_name['requested_items']
_REQUESTITEM.oneofs_by_name['requested_items'].fields.append(
  _REQUESTITEM.fields_by_name['get_events_by_event_access_path_request'])
_REQUESTITEM.fields_by_name['get_events_by_event_access_path_request'].containing_oneof = _REQUESTITEM.oneofs_by_name['requested_items']
_REQUESTITEM.oneofs_by_name['requested_items'].fields.append(
  _REQUESTITEM.fields_by_name['get_transactions_request'])
_REQUESTITEM.fields_by_name['get_transactions_request'].containing_oneof = _REQUESTITEM.oneofs_by_name['requested_items']
_UPDATETOLATESTLEDGERRESPONSE.fields_by_name['response_items'].message_type = _RESPONSEITEM
_UPDATETOLATESTLEDGERRESPONSE.fields_by_name['ledger_info_with_sigs'].message_type = ledger__info__pb2._LEDGERINFOWITHSIGNATURES
_UPDATETOLATESTLEDGERRESPONSE.fields_by_name['validator_change_events'].message_type = validator__change__pb2._VALIDATORCHANGEEVENTWITHPROOF
_RESPONSEITEM.fields_by_name['get_account_state_response'].message_type = _GETACCOUNTSTATERESPONSE
_RESPONSEITEM.fields_by_name['get_account_transaction_by_sequence_number_response'].message_type = _GETACCOUNTTRANSACTIONBYSEQUENCENUMBERRESPONSE
_RESPONSEITEM.fields_by_name['get_events_by_event_access_path_response'].message_type = _GETEVENTSBYEVENTACCESSPATHRESPONSE
_RESPONSEITEM.fields_by_name['get_transactions_response'].message_type = _GETTRANSACTIONSRESPONSE
_RESPONSEITEM.oneofs_by_name['response_items'].fields.append(
  _RESPONSEITEM.fields_by_name['get_account_state_response'])
_RESPONSEITEM.fields_by_name['get_account_state_response'].containing_oneof = _RESPONSEITEM.oneofs_by_name['response_items']
_RESPONSEITEM.oneofs_by_name['response_items'].fields.append(
  _RESPONSEITEM.fields_by_name['get_account_transaction_by_sequence_number_response'])
_RESPONSEITEM.fields_by_name['get_account_transaction_by_sequence_number_response'].containing_oneof = _RESPONSEITEM.oneofs_by_name['response_items']
_RESPONSEITEM.oneofs_by_name['response_items'].fields.append(
  _RESPONSEITEM.fields_by_name['get_events_by_event_access_path_response'])
_RESPONSEITEM.fields_by_name['get_events_by_event_access_path_response'].containing_oneof = _RESPONSEITEM.oneofs_by_name['response_items']
_RESPONSEITEM.oneofs_by_name['response_items'].fields.append(
  _RESPONSEITEM.fields_by_name['get_transactions_response'])
_RESPONSEITEM.fields_by_name['get_transactions_response'].containing_oneof = _RESPONSEITEM.oneofs_by_name['response_items']
_GETACCOUNTSTATERESPONSE.fields_by_name['account_state_with_proof'].message_type = account__state__blob__pb2._ACCOUNTSTATEWITHPROOF
_GETACCOUNTTRANSACTIONBYSEQUENCENUMBERRESPONSE.fields_by_name['signed_transaction_with_proof'].message_type = transaction__pb2._SIGNEDTRANSACTIONWITHPROOF
_GETACCOUNTTRANSACTIONBYSEQUENCENUMBERRESPONSE.fields_by_name['proof_of_current_sequence_number'].message_type = account__state__blob__pb2._ACCOUNTSTATEWITHPROOF
_GETEVENTSBYEVENTACCESSPATHREQUEST.fields_by_name['access_path'].message_type = access__path__pb2._ACCESSPATH
_GETEVENTSBYEVENTACCESSPATHRESPONSE.fields_by_name['events_with_proof'].message_type = events__pb2._EVENTWITHPROOF
_GETEVENTSBYEVENTACCESSPATHRESPONSE.fields_by_name['proof_of_latest_event'].message_type = account__state__blob__pb2._ACCOUNTSTATEWITHPROOF
_GETTRANSACTIONSRESPONSE.fields_by_name['txn_list_with_proof'].message_type = transaction__pb2._TRANSACTIONLISTWITHPROOF
DESCRIPTOR.message_types_by_name['UpdateToLatestLedgerRequest'] = _UPDATETOLATESTLEDGERREQUEST
DESCRIPTOR.message_types_by_name['RequestItem'] = _REQUESTITEM
DESCRIPTOR.message_types_by_name['UpdateToLatestLedgerResponse'] = _UPDATETOLATESTLEDGERRESPONSE
DESCRIPTOR.message_types_by_name['ResponseItem'] = _RESPONSEITEM
DESCRIPTOR.message_types_by_name['GetAccountStateRequest'] = _GETACCOUNTSTATEREQUEST
DESCRIPTOR.message_types_by_name['GetAccountStateResponse'] = _GETACCOUNTSTATERESPONSE
DESCRIPTOR.message_types_by_name['GetAccountTransactionBySequenceNumberRequest'] = _GETACCOUNTTRANSACTIONBYSEQUENCENUMBERREQUEST
DESCRIPTOR.message_types_by_name['GetAccountTransactionBySequenceNumberResponse'] = _GETACCOUNTTRANSACTIONBYSEQUENCENUMBERRESPONSE
DESCRIPTOR.message_types_by_name['GetEventsByEventAccessPathRequest'] = _GETEVENTSBYEVENTACCESSPATHREQUEST
DESCRIPTOR.message_types_by_name['GetEventsByEventAccessPathResponse'] = _GETEVENTSBYEVENTACCESSPATHRESPONSE
DESCRIPTOR.message_types_by_name['GetTransactionsRequest'] = _GETTRANSACTIONSREQUEST
DESCRIPTOR.message_types_by_name['GetTransactionsResponse'] = _GETTRANSACTIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpdateToLatestLedgerRequest = _reflection.GeneratedProtocolMessageType('UpdateToLatestLedgerRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATETOLATESTLEDGERREQUEST,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.UpdateToLatestLedgerRequest)
  ))
_sym_db.RegisterMessage(UpdateToLatestLedgerRequest)

RequestItem = _reflection.GeneratedProtocolMessageType('RequestItem', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTITEM,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.RequestItem)
  ))
_sym_db.RegisterMessage(RequestItem)

UpdateToLatestLedgerResponse = _reflection.GeneratedProtocolMessageType('UpdateToLatestLedgerResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATETOLATESTLEDGERRESPONSE,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.UpdateToLatestLedgerResponse)
  ))
_sym_db.RegisterMessage(UpdateToLatestLedgerResponse)

ResponseItem = _reflection.GeneratedProtocolMessageType('ResponseItem', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEITEM,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.ResponseItem)
  ))
_sym_db.RegisterMessage(ResponseItem)

GetAccountStateRequest = _reflection.GeneratedProtocolMessageType('GetAccountStateRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSTATEREQUEST,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.GetAccountStateRequest)
  ))
_sym_db.RegisterMessage(GetAccountStateRequest)

GetAccountStateResponse = _reflection.GeneratedProtocolMessageType('GetAccountStateResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTSTATERESPONSE,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.GetAccountStateResponse)
  ))
_sym_db.RegisterMessage(GetAccountStateResponse)

GetAccountTransactionBySequenceNumberRequest = _reflection.GeneratedProtocolMessageType('GetAccountTransactionBySequenceNumberRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTTRANSACTIONBYSEQUENCENUMBERREQUEST,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.GetAccountTransactionBySequenceNumberRequest)
  ))
_sym_db.RegisterMessage(GetAccountTransactionBySequenceNumberRequest)

GetAccountTransactionBySequenceNumberResponse = _reflection.GeneratedProtocolMessageType('GetAccountTransactionBySequenceNumberResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTTRANSACTIONBYSEQUENCENUMBERRESPONSE,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.GetAccountTransactionBySequenceNumberResponse)
  ))
_sym_db.RegisterMessage(GetAccountTransactionBySequenceNumberResponse)

GetEventsByEventAccessPathRequest = _reflection.GeneratedProtocolMessageType('GetEventsByEventAccessPathRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETEVENTSBYEVENTACCESSPATHREQUEST,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.GetEventsByEventAccessPathRequest)
  ))
_sym_db.RegisterMessage(GetEventsByEventAccessPathRequest)

GetEventsByEventAccessPathResponse = _reflection.GeneratedProtocolMessageType('GetEventsByEventAccessPathResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETEVENTSBYEVENTACCESSPATHRESPONSE,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.GetEventsByEventAccessPathResponse)
  ))
_sym_db.RegisterMessage(GetEventsByEventAccessPathResponse)

GetTransactionsRequest = _reflection.GeneratedProtocolMessageType('GetTransactionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTRANSACTIONSREQUEST,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.GetTransactionsRequest)
  ))
_sym_db.RegisterMessage(GetTransactionsRequest)

GetTransactionsResponse = _reflection.GeneratedProtocolMessageType('GetTransactionsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTRANSACTIONSRESPONSE,
  __module__ = 'get_with_proof_pb2'
  # @@protoc_insertion_point(class_scope:types.GetTransactionsResponse)
  ))
_sym_db.RegisterMessage(GetTransactionsResponse)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: access_path.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='access_path.proto',
  package='types',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x11\x61\x63\x63\x65ss_path.proto\x12\x05types\"+\n\nAccessPath\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\x0c\x62\x06proto3')
)




_ACCESSPATH = _descriptor.Descriptor(
  name='AccessPath',
  full_name='types.AccessPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='types.AccessPath.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='types.AccessPath.path', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28,
  serialized_end=71,
)

DESCRIPTOR.message_types_by_name['AccessPath'] = _ACCESSPATH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccessPath = _reflection.GeneratedProtocolMessageType('AccessPath', (_message.Message,), dict(
  DESCRIPTOR = _ACCESSPATH,
  __module__ = 'access_path_pb2'
  # @@protoc_insertion_point(class_scope:types.AccessPath)
  ))
_sym_db.RegisterMessage(AccessPath)


# @@protoc_insertion_point(module_scope)
